@@ -1,6 +1,8 @@
+import logging
+
 import numpy
 
-from pytolemaic.analysis_logic.dataset_analysis.dataset_analysis import DatasetAnalysis
+from pytolemaic.analysis_logic.dataset_analysis.dataset_analysis import DatasetAnalysis, CovarianceShift
 from pytolemaic.analysis_logic.dataset_analysis.dataset_analysis_report import DatasetAnalysisReport
 from pytolemaic.analysis_logic.model_analysis.scoring.scoring import \
     Scoring
@@ -89,6 +91,16 @@ class PyTrust():
             else:
                 raise NotImplementedError("splitter='{}' is not supported".format(splitter))
 
+        if ytrain is not None:
+            shape = getattr(ytrain, 'shape', (1, 1))
+            if len(shape) == 2 and shape[1] > 1:
+                raise NotImplementedError("Pytrust does not support multilabel (ytrain.shape[1]>1) analysis. "
+                                          "In order to use Pytolemaic package, please wrap you model so model.predict(X) will return a single vector. ")
+        if ytest is not None:
+            shape = getattr(ytest, 'shape', (1, 1))
+            if len(shape) == 2 and shape[1] > 1:
+                raise NotImplementedError("Pytrust does not support multilabel (ytest.shape[1]>1) analysis. "
+                                          "In order to use Pytolemaic package, please wrap you model so model.predict(X) will return a single vector. ")
 
         self.train = xtrain
         if self.train is not None and not isinstance(self.train, DMD):
@@ -137,6 +149,17 @@ class PyTrust():
     @classmethod
     def create_sensitivity_report(cls, model, train: DMD, test: DMD, metric: str,
                                   sensitivity: SensitivityAnalysis = None, **kwargs) -> SensitivityFullReport:
+        """
+        Create sensitivity report
+        Args:
+            model - model to be analyzed based on test data
+            train - train data (DMD). Train data is used if test is None
+            test - test data (DMD). If None, use train data instead.
+            sensitivity - SensitivityAnalysis instance. If None, instance is initiated internally.
+
+        Returns:
+            sensitivity report
+        """
         sensitivity = sensitivity or SensitivityAnalysis()
         sensitivity.calculate_sensitivity(
             model=model, dmd_test=test, dmd_train=train, metric=metric, **kwargs)
@@ -144,8 +167,19 @@ class PyTrust():
         return sensitivity.sensitivity_report(**kwargs)
 
     @classmethod
-    def create_scoring_report(cls, model, train: DMD, test: DMD, metric: str, y_pred=None, y_proba=None,
+    def create_scoring_report(cls, model, test: DMD, metric: str, y_pred=None, y_proba=None,
                               scoring: Scoring = None, **kwargs) -> ScoringFullReport:
+        """
+        Create scoring report
+        Args:
+            model - model to be analyzed based on test data
+            train - train data (DMD). Train data is used only for separability test
+            test - test data (DMD). .
+            scoring - Scoring instance. If None, instance is initiated internally.
+
+        Returns:
+            scoring report
+        """
         metrics = Metrics.supported_metrics()
 
         scoring = scoring or Scoring(metrics=metrics)
@@ -157,22 +191,24 @@ class PyTrust():
                                        y_pred=y_pred,
                                        y_proba=y_proba)
 
-        if train is not None and test is not None:
-            separation_quality = scoring.separation_quality(dmd_train=train, dmd_test=test)
-        else:
-            separation_quality = numpy.nan
-
         return ScoringFullReport(target_metric=metric,
                                  metric_reports=score_values_report,
-                                 separation_quality=separation_quality,
                                  confusion_matrix=confusion_matrix,
                                  scatter=scatter,
                                  classification_report=classification_report)
 
     @classmethod
     def create_quality_report(cls, scoring_report: ScoringFullReport,
-                              sensitivity_report: SensitivityFullReport) -> QualityReport:
-        test_set_report = TestSetQualityReport(scoring_report=scoring_report)
+                              sensitivity_report: SensitivityFullReport,
+                              dataset_analysis_report: DatasetAnalysisReport) -> QualityReport:
+        """
+        Create quality report by analyzing scoring_report & sensitivity_report
+
+        Returns:
+            quality report
+        """
+        test_set_report = TestSetQualityReport(scoring_report=scoring_report,
+                                               dataset_analysis_report=dataset_analysis_report)
 
         train_set_report = TrainSetQualityReport(vulnerability_report=sensitivity_report.vulnerability_report)
         model_quality_report = ModelQualityReport(vulnerability_report=sensitivity_report.vulnerability_report,
@@ -182,15 +218,52 @@ class PyTrust():
                              model_quality_report=model_quality_report)
 
     @classmethod
-    def create_dataset_analysis_report(cls, train: DMD, is_classification, **kwargs) -> DatasetAnalysisReport:
-        da = DatasetAnalysis(problem_Type=CLASSIFICATION if is_classification else REGRESSION)
-        report = da.dataset_analysis_report(dataset=train)
+    def create_dataset_analysis_report(cls, train: DMD, is_classification, test:DMD=None, dataset_analysis: DatasetAnalysis=None, **kwargs) -> DatasetAnalysisReport:
+        """
+        Create dataset analysis report by analyzing train data
+
+        Args:
+            train - train data
+            test - test data, if available
+            is_classification - whether the target is categorical.
+
+        Returns:
+            dataset analysis report
+        """
+        dataset_analysis = dataset_analysis or DatasetAnalysis(problem_Type=CLASSIFICATION if is_classification else REGRESSION)
+        report = dataset_analysis.dataset_analysis_report(train=train, test=test)
         return report
 
     @classmethod
     def create_pytrust_report(cls, pytrust) -> PyTrustReport:
+        """
+             Creates final report encompassing all other reports for entire pytrust.
+             Returns:
+                 pytrust report
+        """
         return PyTrustReport(pytrust=pytrust)
 
+    @classmethod
+    def create_pytrust_for_separability_test(cls, train: DMD, test: DMD, **pytrust_kwargs):
+        """
+        Create scoring report
+        Args:
+            train - train data (DMD).
+            test - test data (DMD).
+
+        Returns:
+            separability pytrust
+        """
+
+        covariance_shift = CovarianceShift()
+        covariance_shift.calc_separation_quality(dmd_train=train, dmd_test=test)
+
+        separability_pytrust = PyTrust(model=covariance_shift.classifier,
+                                       xtrain=covariance_shift.train,
+                                       xtest=covariance_shift.test,
+                                       **pytrust_kwargs)
+        return separability_pytrust
+
     # endregion
 
     # region reports
@@ -208,14 +281,21 @@ class PyTrust():
 
     def _create_quality_report(self) -> QualityReport:
         return self.create_quality_report(scoring_report=self.scoring_report,
-                                          sensitivity_report=self.sensitivity_report)
+                                          sensitivity_report=self.sensitivity_report,
+                                          dataset_analysis_report=self.dataset_analysis_report)
 
     def _create_dataset_analysis_report(self, **kwargs) -> DatasetAnalysisReport:
-        return self.create_dataset_analysis_report(train=self.train, is_classification=self.is_classification)
+        self.dataset_analysis = DatasetAnalysis(problem_Type=CLASSIFICATION if self.is_classification else REGRESSION)
+        return self.create_dataset_analysis_report(train=self.train, test=self.test, is_classification=self.is_classification,
+                                                   dataset_analysis=self.dataset_analysis)
 
     def _create_pytrust_report(self):
         return self.create_pytrust_report(pytrust=self)
 
+    def _create_pytrust_for_separability_test(self):
+        return self.create_pytrust_for_separability_test(
+            train=self.train, test=self.test, metric=self.metric)
+
     # endregion
 
     # region on predict
@@ -310,6 +390,11 @@ class PyTrust():
     def insights(self) -> list:
         return self.report.insights()
 
+    @property
+    @cache
+    def pytrust_for_separability_test(self):
+        return self._create_pytrust_for_separability_test()
+
     @classmethod
     def print_initialization_example(cls):
         example = \
@@ -328,7 +413,7 @@ class PyTrust():
                 
         # See usage example below:\n
         """
-        print(example)
+        logging.info(example)
         example += cls.print_usage_example()
         return example
 
@@ -387,7 +472,8 @@ class PyTrust():
             example.append('\n**************\n')
 
         example = "\n".join(example)
-        print(example)
+        logging.info(example)
         return example
 
+
     # endregion
